/*============================================================================
  File:     GenerateBackups.sql

  Summary:  This script generates a "backup strategy" of backups:
            
                Sunday = Full backup
                Monday
                    6 hour differentials
                    1 hour log backups (except at differential hour)
                Tuesday
                    6 hour differentials
                    1 hour log backups (except at differential hour)
                Wednesday
                    6 hour differentials
                    1 hour log backups

                Then, we'll add a table/data (this will be in the "tail" of the log)
                
                Next, we'll "CRASH" the server and simulate disaster (after 3rd log backup)

  SQL Server Versions: 2005+
------------------------------------------------------------------------------
  Written by SQLskills.com

  (c) SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- Cleanout the backup history
USE msdb;
GO

EXEC sp_delete_database_backuphistory 'DBMaint2008'
GO

USE master;
GO

IF DATABASEPROPERTYEX ('DBMaint2008', 'Version') > 0
	DROP DATABASE DBMaint2008;

-- Create the database
CREATE DATABASE DBMaint2008;
GO

-- Create a table that will grow
-- large quickly
CREATE TABLE DBMaint2008..TestTable (
	c1 INT IDENTITY,
	c2 CHAR (8000) DEFAULT 'a');
GO
SET NOCOUNT ON;
GO

INSERT INTO DBMaint2008..TestTable
	DEFAULT VALUES;
GO 1000

-- And take Sunday full backup
BACKUP DATABASE DBMaint2008 TO DISK =
	'C:\SQLskills\DBMaint2008_Full_Sunday.bak'
WITH INIT;
GO

BACKUP LOG DBMaint2008 TO DISK =
	'C:\SQLskills\DBMaint2008_Log_Monday.bak'
WITH INIT;
GO

-- Now add more data, hourly log backups
-- and 6-hr differential backups for Monday
DECLARE @count INT;
SELECT @count = 1;
WHILE @count < 25
BEGIN
	INSERT INTO DBmaint2008..TestTable
		DEFAULT VALUES;

	BACKUP LOG DBMaint2008 TO DISK =
		'C:\SQLskills\DBMaint2008_Log_Monday.bak';

	IF (@count % 6 = 0)
	BEGIN
		BACKUP DATABASE DBMaint2008 TO DISK =
			'C:\SQLskills\DBMaint2008_Diff_Monday.bak'
		WITH DIFFERENTIAL;
	END

	SELECT @count = @count + 1;

	WAITFOR DELAY '00:00:01';
END
GO

-- Now add more data, hourly log backups
-- and 6-hr differential backups for Tuesday
DECLARE @count INT;
SELECT @count = 1;
WHILE @count < 25
BEGIN
	INSERT INTO DBmaint2008..TestTable
		DEFAULT VALUES;

	BACKUP LOG DBMaint2008 TO DISK =
		'C:\SQLskills\DBMaint2008_Log_Tuesday.bak';

	IF (@count % 6 = 0)
	BEGIN
		BACKUP DATABASE DBMaint2008 TO DISK =
			'C:\SQLskills\DBMaint2008_Diff_Tuesday.bak'
		WITH DIFFERENTIAL;
	END

	SELECT @count = @count + 1;

	WAITFOR DELAY '00:00:01';
END
GO
	
-- Now add more data and hourly log
-- backups for Wednesday, but we crash
-- just after the 3am backup
DECLARE @count INT;
SELECT @count = 1;
WHILE @count < 4
BEGIN
	INSERT INTO DBmaint2008..TestTable
		DEFAULT VALUES;

	BACKUP LOG DBMaint2008 TO DISK =
		'C:\SQLskills\DBMaint2008_Log_Wednesday.bak';

	SELECT @count = @count + 1;

	WAITFOR DELAY '00:00:01';
END
GO

-- All of our backups have been performed and now we'll
-- add some more data... this will be in the "tail of the
-- log" at the time of the crash.

CREATE TABLE DBMaint2008..ReallyImportantTable (
	c1 INT IDENTITY,
	c2 CHAR (8000) DEFAULT 'critical information!!');
GO
SET NOCOUNT ON;
GO

INSERT INTO DBMaint2008..ReallyImportantTable
	DEFAULT VALUES;
GO 20